@@ -19,7 +19,6 @@
  *
  */
 
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const _ = imports.gettext.gettext;
 
@@ -38,7 +37,6 @@ const Format = imports.format;
 const MainWindow = imports.mainWindow;
 const Miners = imports.miners;
 const Notifications = imports.notifications;
-const Properties = imports.properties;
 const Query = imports.query;
 const Search = imports.search;
 const Selections = imports.selections;
@@ -92,14 +90,12 @@ function TrackerExtractPriority() {
 
 const MINER_REFRESH_TIMEOUT = 60; /* seconds */
 
-var Application = new Lang.Class({
-    Name: 'Application',
-    Extends: Gtk.Application,
+var Application = GObject.registerClass({
     Signals: {
         'miners-changed': {}
-    },
-
-    _init: function() {
+    }
+}, class Application extends Gtk.Application {
+    _init() {
         this.minersRunning = [];
         this._activationTimestamp = Gdk.CURRENT_TIME;
         this._extractPriority = null;
@@ -112,14 +108,14 @@ var Application = new Lang.Class({
         // needed by data/ui/view-menu.ui
         GObject.type_ensure(Gio.ThemedIcon);
 
-        this.parent({ application_id: appid,
+        super._init({ application_id: appid,
                       inactivity_timeout: 12000 });
 
         this.add_main_option('version', 'v'.charCodeAt(0), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
                              _("Show the version of the program"), null);
-    },
+    }
 
-    _initGettingStarted: function() {
+    _initGettingStarted() {
         let manager = TrackerControl.MinerManager.new_full(false);
 
         let languages = GLib.get_language_names();
@@ -153,33 +149,32 @@ var Application = new Lang.Class({
 
         if (!this.gettingStartedLocation)
             log('Can\'t find a valid getting started PDF document');
-    },
+    }
 
-    _nightModeCreateHook: function(action) {
-        settings.connect('changed::night-mode', Lang.bind(this,
-            function() {
-                let state = settings.get_value('night-mode');
-                if (state.get_boolean() != action.state.get_boolean())
-                    action.change_state(state);
+    _nightModeCreateHook(action) {
+        settings.connect('changed::night-mode', () => {
+            let state = settings.get_value('night-mode');
+            if (state.get_boolean() != action.state.get_boolean())
+                action.change_state(state);
 
-                let gtkSettings = Gtk.Settings.get_default();
-                gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
-            }));
+            let gtkSettings = Gtk.Settings.get_default();
+            gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
+        });
 
         let state = settings.get_value('night-mode');
         let gtkSettings = Gtk.Settings.get_default();
         gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
-    },
+    }
 
-    _onActionQuit: function() {
+    _onActionQuit() {
         this._mainWindow.destroy();
-    },
+    }
 
-    _onActionAbout: function() {
+    _onActionAbout() {
         this._mainWindow.showAbout();
-    },
+    }
 
-    _onActionHelp: function() {
+    _onActionHelp() {
         try {
             Gtk.show_uri_on_window(this._mainWindow,
                                    'help:gnome-documents',
@@ -187,39 +182,36 @@ var Application = new Lang.Class({
         } catch (e) {
             logError(e, 'Unable to display help');
         }
-    },
+    }
 
-    _onActionNightMode: function(action) {
+    _onActionNightMode(action) {
         let state = action.get_state();
         settings.set_value('night-mode', GLib.Variant.new('b', !state.get_boolean()));
-    },
+    }
 
-    _createMiners: function(callback) {
+    _createMiners(callback) {
         let count = 3;
 
-        this.gdataMiner = new Miners.GDataMiner(Lang.bind(this,
-            function() {
-                count--;
-                if (count == 0)
-                    callback();
-            }));
+        this.gdataMiner = new Miners.GDataMiner(() => {
+            count--;
+            if (count == 0)
+                callback();
+        });
 
-        this.owncloudMiner = new Miners.OwncloudMiner(Lang.bind(this,
-            function() {
-                count--;
-                if (count == 0)
-                    callback();
-            }));
+        this.owncloudMiner = new Miners.OwncloudMiner(() => {
+            count--;
+            if (count == 0)
+                callback();
+        });
 
-        this.zpjMiner = new Miners.ZpjMiner(Lang.bind(this,
-            function() {
-                count--;
-                if (count == 0)
-                    callback();
-            }));
-    },
+        this.zpjMiner = new Miners.ZpjMiner(() => {
+            count--;
+            if (count == 0)
+                callback();
+        });
+    }
 
-    _refreshMinerNow: function(miner) {
+    _refreshMinerNow(miner) {
         let env = GLib.getenv('DOCUMENTS_DISABLE_MINERS');
         if (env)
             return false;
@@ -231,31 +223,30 @@ var Application = new Lang.Class({
         this.emit('miners-changed');
 
         miner._cancellable = new Gio.Cancellable();
-        miner.RefreshDBRemote(['documents'], miner._cancellable, Lang.bind(this,
-            function(res, error) {
-                this.minersRunning = this.minersRunning.filter(
-                    function(element) {
-                        return element != miner;
-                    });
-                this.emit('miners-changed');
+        miner.RefreshDBRemote(['documents'], miner._cancellable, (res, error) => {
+            this.minersRunning = this.minersRunning.filter(
+                function(element) {
+                    return element != miner;
+                });
+            this.emit('miners-changed');
 
-                if (error) {
-                    if (!error.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.CANCELLED))
-                        logError(error, 'Error updating the cache');
+            if (error) {
+                if (!error.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.CANCELLED))
+                    logError(error, 'Error updating the cache');
 
-                    return;
-                }
+                return;
+            }
 
-                Mainloop.timeout_add_seconds(MINER_REFRESH_TIMEOUT,
-                                             Lang.bind(this, function() {
-                                                 this._refreshMinerNow(miner);
-                                             }));
-            }));
+            Mainloop.timeout_add_seconds(MINER_REFRESH_TIMEOUT, () => {
+                this._refreshMinerNow(miner);
+                return false;
+            });
+        });
 
         return false;
-    },
+    }
 
-    _refreshMiners: function() {
+    _refreshMiners() {
         if (sourceManager.hasProviderType('google')) {
             try {
                 // startup a refresh of the gdocs cache
@@ -282,21 +273,18 @@ var Application = new Lang.Class({
                 logError(e, 'Unable to start Zpj miner');
             }
         }
-    },
+    }
 
-    _startMiners: function() {
-        this._createMiners(Lang.bind(this,
-            function() {
-                this._refreshMiners();
+    _startMiners() {
+        this._createMiners(() => {
+            this._refreshMiners();
 
-                this._sourceAddedId = sourceManager.connect('item-added',
-                                                            Lang.bind(this, this._refreshMiners));
-                this._sourceRemovedId = sourceManager.connect('item-removed',
-                                                              Lang.bind(this, this._refreshMiners));
-            }));
-    },
+            this._sourceAddedId = sourceManager.connect('item-added', this._refreshMiners.bind(this));
+            this._sourceRemovedId = sourceManager.connect('item-removed', this._refreshMiners.bind(this));
+        });
+    }
 
-    _stopMiners: function() {
+    _stopMiners() {
         if (this._sourceAddedId != 0) {
             sourceManager.disconnect(this._sourceAddedId);
             this._sourceAddedId = 0;
@@ -307,18 +295,17 @@ var Application = new Lang.Class({
             this._sourceRemovedId = 0;
         }
 
-        this.minersRunning.forEach(Lang.bind(this,
-            function(miner) {
-                miner._cancellable.cancel();
-            }));
+        this.minersRunning.forEach(() => {
+            miner._cancellable.cancel();
+        });
         this.minersRunning = [];
 
         this.gdataMiner = null;
         this.owncloudMiner = null;
         this.zpjMiner = null;
-    },
+    }
 
-    _themeChanged: function(gtkSettings) {
+    _themeChanged(gtkSettings) {
         let screen = Gdk.Screen.get_default();
 
         if (gtkSettings.gtk_theme_name == 'Adwaita') {
@@ -334,11 +321,11 @@ var Application = new Lang.Class({
         } else if (cssProvider != null) {
             Gtk.StyleContext.remove_provider_for_screen(screen, cssProvider);
         }
-    },
+    }
 
-    vfunc_startup: function() {
+    vfunc_startup() {
         application = this;
-        this.parent();
+        super.vfunc_startup();
         String.prototype.format = Format.format;
 
         EvDoc.init();
@@ -346,7 +333,7 @@ var Application = new Lang.Class({
         settings = new Gio.Settings({ schema_id: 'org.gnome.documents' });
 
         let gtkSettings = Gtk.Settings.get_default();
-        gtkSettings.connect('notify::gtk-theme-name', Lang.bind(this, this._themeChanged));
+        gtkSettings.connect('notify::gtk-theme-name', this._themeChanged.bind(this));
         this._themeChanged(gtkSettings);
 
         // connect to tracker
@@ -382,23 +369,23 @@ var Application = new Lang.Class({
 
         let actionEntries = [
             { name: 'quit',
-              callback: Lang.bind(this, this._onActionQuit),
+              callback: this._onActionQuit.bind(this),
               accels: ['<Primary>q'] },
             { name: 'about',
-              callback: Lang.bind(this, this._onActionAbout) },
+              callback: this._onActionAbout.bind(this) },
             { name: 'help',
-              callback: Lang.bind(this, this._onActionHelp),
+              callback: this._onActionHelp.bind(this),
               accels: ['F1'] },
             { name: 'night-mode',
-              callback: Lang.bind(this, this._onActionNightMode),
-              create_hook: Lang.bind(this, this._nightModeCreateHook),
+              callback: this._onActionNightMode.bind(this),
+              create_hook: this._nightModeCreateHook.bind(this),
               state: settings.get_value('night-mode') },
         ];
 
         Utils.populateActionGroup(this, actionEntries, 'app');
-    },
+    }
 
-    _createWindow: function() {
+    _createWindow() {
         if (this._mainWindow)
             return;
 
@@ -406,7 +393,7 @@ var Application = new Lang.Class({
 
         notificationManager = new Notifications.NotificationManager();
         this._mainWindow = new MainWindow.MainWindow(this);
-        this._mainWindow.connect('destroy', Lang.bind(this, this._onWindowDestroy));
+        this._mainWindow.connect('destroy', this._onWindowDestroy.bind(this));
 
         try {
             this._extractPriority = TrackerExtractPriority();
@@ -417,17 +404,17 @@ var Application = new Lang.Class({
 
         // start miners
         this._startMiners();
-    },
+    }
 
-    vfunc_dbus_register: function(connection, path) {
-        this.parent(connection, path);
+    vfunc_dbus_register(connection, path) {
+        super.vfunc_dbus_register(connection, path);
 
         if (this._searchProvider != null)
             throw(new Error('ShellSearchProvider already instantiated - dbus_register called twice?'));
 
         this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
-        this._searchProvider.connect('activate-result', Lang.bind(this, this._onActivateResult));
-        this._searchProvider.connect('launch-search', Lang.bind(this, this._onLaunchSearch));
+        this._searchProvider.connect('activate-result', this._onActivateResult.bind(this));
+        this._searchProvider.connect('launch-search', this._onLaunchSearch.bind(this));
 
         try {
             this._searchProvider.export(connection);
@@ -437,27 +424,27 @@ var Application = new Lang.Class({
         }
 
         return true;
-    },
+    }
 
-    vfunc_dbus_unregister: function(connection, path) {
+    vfunc_dbus_unregister(connection, path) {
         if (this._searchProvider != null) {
             this._searchProvider.unexport(connection);
             this._searchProvider = null;
         }
 
-        this.parent(connection, path);
-    },
+        super.vfunc_dbus_unregister(connection, path);
+    }
 
-    vfunc_handle_local_options: function(options) {
+    vfunc_handle_local_options(options) {
         if (options.contains('version')) {
             print(pkg.version);
             return 0;
         }
 
         return -1;
-    },
+    }
 
-    vfunc_activate: function() {
+    vfunc_activate() {
         if (!this._mainWindow) {
             this._createWindow();
             modeController.setWindowMode(WindowMode.WindowMode.DOCUMENTS);
@@ -465,9 +452,9 @@ var Application = new Lang.Class({
 
         this._mainWindow.present_with_time(this._activationTimestamp);
         this._activationTimestamp = Gdk.CURRENT_TIME;
-    },
+    }
 
-    _clearState: function() {
+    _clearState() {
         // clean up signals
         changeMonitor.disconnectAll();
         documentManager.disconnectAll();
@@ -492,17 +479,17 @@ var Application = new Lang.Class({
 
         if (this._extractPriority)
             this._extractPriority.ClearRdfTypesRemote();
-    },
+    }
 
-    _onWindowDestroy: function(window) {
+    _onWindowDestroy(window) {
         this._mainWindow = null;
 
         // clear our state in an idle, so other handlers connected
         // to 'destroy' have the chance to perform their cleanups first
-        Mainloop.idle_add(Lang.bind(this, this._clearState));
-    },
+        Mainloop.idle_add(this._clearState.bind(this));
+    }
 
-    _onActivateResult: function(provider, urn, terms, timestamp) {
+    _onActivateResult(provider, urn, terms, timestamp) {
         this._createWindow();
 
         let doc = documentManager.getItemById(urn);
@@ -510,13 +497,12 @@ var Application = new Lang.Class({
             doActivate.apply(this, [doc]);
         } else {
             let job = new TrackerUtils.SingleItemJob(urn, queryBuilder);
-            job.run(Query.QueryFlags.UNFILTERED, Lang.bind(this,
-                function(cursor) {
-                    if (cursor)
-                        doc = documentManager.addDocumentFromCursor(cursor);
+            job.run(Query.QueryFlags.UNFILTERED, (cursor) => {
+                if (cursor)
+                    doc = documentManager.addDocumentFromCursor(cursor);
 
-                    doActivate.apply(this, [doc]);
-                }));
+                doActivate.apply(this, [doc]);
+            });
         }
 
         function doActivate(doc) {
@@ -526,34 +512,33 @@ var Application = new Lang.Class({
             this.activate();
 
             // forward the search terms next time we enter the overview
-            let modeChangeId = modeController.connect('window-mode-changed', Lang.bind(this,
-                function(object, newMode) {
-                    if (newMode == WindowMode.WindowMode.DOCUMENTS) {
-                        modeController.disconnect(modeChangeId);
-                        searchController.setString(terms.join(' '));
-                    }
-                }));
+            let modeChangeId = modeController.connect('window-mode-changed', (object, newMode) => {
+                if (newMode == WindowMode.WindowMode.DOCUMENTS) {
+                    modeController.disconnect(modeChangeId);
+                    searchController.setString(terms.join(' '));
+                }
+            });
         }
-    },
+    }
 
-    _onLaunchSearch: function(provider, terms, timestamp) {
+    _onLaunchSearch(provider, terms, timestamp) {
         this._createWindow();
         modeController.setWindowMode(WindowMode.WindowMode.DOCUMENTS);
         searchController.setString(terms.join(' '));
 
         this._activationTimestamp = timestamp;
         this.activate();
-    },
+    }
 
-    getScaleFactor: function() {
+    getScaleFactor() {
         let scaleFactor = 1;
         if (this._mainWindow)
             scaleFactor = this._mainWindow.get_scale_factor();
 
         return scaleFactor;
-    },
+    }
 
-    getGdkWindow: function() {
+    getGdkWindow() {
         let window = null;
         if (this._mainWindow)
             window = this._mainWindow.get_window();
