@@ -24,7 +24,6 @@ const Documents = imports.documents;
 const Manager = imports.manager;
 const Query = imports.query;
 
-const Lang = imports.lang;
 const Signals = imports.signals;
 
 const Gio = imports.gi.Gio;
@@ -42,62 +41,56 @@ function initSearch(context) {
     context.queryBuilder = new Query.QueryBuilder(context);
 };
 
-const SearchState = new Lang.Class({
-    Name: 'SearchState',
-
-    _init: function(searchMatch, searchType, source, str) {
+const SearchState = class SearchState {
+    constructor(searchMatch, searchType, source, str) {
         this.searchMatch = searchMatch;
         this.searchType = searchType;
         this.source = source;
         this.str = str;
     }
-});
+}
 
-const SearchController = new Lang.Class({
-    Name: 'SearchController',
-
-    _init: function() {
+const SearchController = class SearchController {
+    constructor() {
         this._string = '';
-    },
+    }
 
-    setString: function(string) {
+    setString(string) {
         if (this._string == string)
             return;
 
         this._string = string;
         this.emit('search-string-changed', this._string);
-    },
+    }
 
-    getString: function() {
+    getString() {
         return this._string;
-    },
+    }
 
-    getTerms: function() {
+    getTerms() {
         let escapedStr = Tracker.sparql_escape_string(this._string);
         let [tokens, ] = GLib.str_tokenize_and_fold(escapedStr, null);
         return tokens;
     }
-});
+}
 Signals.addSignalMethods(SearchController.prototype);
 
-const SearchType = new Lang.Class({
-    Name: 'SearchType',
-
-    _init: function(params) {
+const SearchType = class SearchType {
+    constructor(params) {
         this.id = params.id;
         this.name = params.name;
         this._filter = (params.filter) ? (params.filter) : '(true)';
         this._where = (params.where) ? (params.where) : '';
-    },
+    }
 
-    getFilter: function() {
+    getFilter() {
         return this._filter;
-    },
+    }
 
-    getWhere: function() {
+    getWhere() {
         return this._where;
     }
-});
+}
 
 var SearchTypeStock = {
     ALL: 'all',
@@ -108,14 +101,11 @@ var SearchTypeStock = {
     TEXTDOCS: 'textdocs'
 };
 
-const SearchTypeManager = new Lang.Class({
-    Name: 'SearchTypeManager',
-    Extends: Manager.BaseManager,
-
-    _init: function(context) {
+const SearchTypeManager = class SearchTypeManager extends Manager.BaseManager {
+    constructor(context) {
         // Translators: "Type" refers to a search filter on the document type
         // (PDF, spreadsheet, ...)
-        this.parent(C_("Search Filter", "Type"), 'search-type', context);
+        super(C_("Search Filter", "Type"), 'search-type', context);
 
         this.addItem(new SearchType({ id: SearchTypeStock.ALL,
                                       name: _("All") }));
@@ -140,18 +130,18 @@ const SearchTypeManager = new Lang.Class({
                                       where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
 
         this.setActiveItemById(SearchTypeStock.ALL);
-    },
+    }
 
-    getCurrentTypes: function() {
+    getCurrentTypes() {
         let activeItem = this.getActiveItem();
 
         if (activeItem.id == SearchTypeStock.ALL)
             return this.getAllTypes();
 
         return [ activeItem ];
-    },
+    }
 
-    getDocumentTypes: function() {
+    getDocumentTypes() {
         let types = [];
 
         types.push(this.getItemById(SearchTypeStock.PDF));
@@ -160,9 +150,9 @@ const SearchTypeManager = new Lang.Class({
         types.push(this.getItemById(SearchTypeStock.TEXTDOCS));
 
         return types;
-    },
+    }
 
-    getAllTypes: function() {
+    getAllTypes() {
         let types = [];
 
         this.forEachItem(function(item) {
@@ -172,7 +162,7 @@ const SearchTypeManager = new Lang.Class({
 
         return types;
     }
-});
+}
 
 var SearchMatchStock = {
     ALL: 'all',
@@ -181,20 +171,18 @@ var SearchMatchStock = {
     CONTENT: 'content'
 };
 
-const SearchMatch = new Lang.Class({
-    Name: 'SearchMatch',
-
-    _init: function(params) {
+const SearchMatch = class SearchMatch {
+    constructor(params) {
         this.id = params.id;
         this.name = params.name;
         this._term = '';
-    },
+    }
 
-    setFilterTerm: function(term) {
+    setFilterTerm(term) {
         this._term = term;
-    },
+    }
 
-    getFilter: function() {
+    getFilter() {
         if (this.id == SearchMatchStock.TITLE)
             return ('fn:contains ' +
                     '(tracker:unaccent(tracker:case-fold' +
@@ -217,17 +205,14 @@ const SearchMatch = new Lang.Class({
             return '(false)';
         return '';
     }
-});
+}
 
-const SearchMatchManager = new Lang.Class({
-    Name: 'SearchMatchManager',
-    Extends: Manager.BaseManager,
-
-    _init: function(context) {
+const SearchMatchManager = class SearchMatchManager extends Manager.BaseManager {
+    constructor(context) {
         // Translators: this is a verb that refers to "All", "Title", "Author",
         // and "Content" as in "Match All", "Match Title", "Match Author", and
         // "Match Content"
-        this.parent(_("Match"), 'search-match', context);
+        super(_("Match"), 'search-match', context);
 
         this.addItem(new SearchMatch({ id: SearchMatchStock.ALL,
                                        name: _("All") }));
@@ -242,9 +227,9 @@ const SearchMatchManager = new Lang.Class({
                                        name: C_("Search Filter", "Content") }));
 
         this.setActiveItemById(SearchMatchStock.ALL);
-    },
+    }
 
-    getWhere: function() {
+    getWhere() {
         let item = this.getActiveItem();
         if (item.id != SearchMatchStock.ALL &&
             item.id != SearchMatchStock.CONTENT)
@@ -261,9 +246,9 @@ const SearchMatchManager = new Lang.Class({
         }
 
         return '?urn fts:match \'%s\' . '.format(ftsterms.join(' '));
-    },
+    }
 
-    getFilter: function(flags) {
+    getFilter(flags) {
         if ((flags & Query.QueryFlags.SEARCH) == 0)
             return '(true)';
 
@@ -287,7 +272,7 @@ const SearchMatchManager = new Lang.Class({
         }
         return filters.length ? '( ' + filters.join(' && ') + ')' : '(true)';
     }
-});
+}
 
 var SearchSourceStock = {
     ALL: 'all',
@@ -297,10 +282,8 @@ var SearchSourceStock = {
 const TRACKER_SCHEMA = 'org.freedesktop.Tracker.Miner.Files';
 const TRACKER_KEY_RECURSIVE_DIRECTORIES = 'index-recursive-directories';
 
-const Source = new Lang.Class({
-    Name: 'Source',
-
-    _init: function(params) {
+const Source = class Source {
+    constructor(params) {
         this.id = null;
         this.name = null;
         this.icon = null;
@@ -318,79 +301,76 @@ const Source = new Lang.Class({
         }
 
         this.builtin = params.builtin;
-    },
+    }
 
-    _getGettingStartedLocations: function() {
+    _getGettingStartedLocations() {
         if (Application.application.gettingStartedLocation)
             return Application.application.gettingStartedLocation;
         else
             return [];
-    },
+    }
 
-    _getTrackerLocations: function() {
+    _getTrackerLocations() {
         let settings = new Gio.Settings({ schema_id: TRACKER_SCHEMA });
         let locations = settings.get_strv(TRACKER_KEY_RECURSIVE_DIRECTORIES);
         let files = [];
 
-        locations.forEach(Lang.bind(this,
-            function(location) {
-                // ignore special XDG placeholders, since we handle those internally
-                if (location[0] == '&' || location[0] == '$')
+        locations.forEach((location) => {
+            // ignore special XDG placeholders, since we handle those internally
+            if (location[0] == '&' || location[0] == '$')
+                return;
+
+            let trackerFile = Gio.file_new_for_commandline_arg(location);
+
+            // also ignore XDG locations if they are present with their full path
+            for (let idx = 0; idx < GLib.UserDirectory.N_DIRECTORIES; idx++) {
+                let path = GLib.get_user_special_dir(idx);
+                if (!path)
+                    continue;
+
+                let file = Gio.file_new_for_path(path);
+                if (trackerFile.equal(file))
                     return;
+            }
 
-                let trackerFile = Gio.file_new_for_commandline_arg(location);
-
-                // also ignore XDG locations if they are present with their full path
-                for (let idx = 0; idx < GLib.UserDirectory.N_DIRECTORIES; idx++) {
-                    let path = GLib.get_user_special_dir(idx);
-                    if (!path)
-                        continue;
-
-                    let file = Gio.file_new_for_path(path);
-                    if (trackerFile.equal(file))
-                        return;
-                }
-
-                files.push(trackerFile);
-            }));
+            files.push(trackerFile);
+        });
 
         return files;
-    },
+    }
 
-    _getBuiltinLocations: function() {
+    _getBuiltinLocations() {
         let files = [];
         let xdgDirs = [GLib.UserDirectory.DIRECTORY_DESKTOP,
                        GLib.UserDirectory.DIRECTORY_DOCUMENTS,
                        GLib.UserDirectory.DIRECTORY_DOWNLOAD];
 
-        xdgDirs.forEach(Lang.bind(this,
-            function(dir) {
-                let path = GLib.get_user_special_dir(dir);
-                if (path)
-                    files.push(Gio.file_new_for_path(path));
-            }));
+        xdgDirs.forEach((dir) => {
+            let path = GLib.get_user_special_dir(dir);
+            if (path)
+                files.push(Gio.file_new_for_path(path));
+        });
 
         return files;
-    },
+    }
 
-    _buildFilterLocal: function() {
+    _buildFilterLocal() {
         let locations = this._getBuiltinLocations();
         locations = locations.concat(
             this._getTrackerLocations(),
             this._getGettingStartedLocations());
 
         let filters = [];
-        locations.forEach(Lang.bind(this,
-            function(location) {
-                filters.push('(fn:contains (nie:url(?urn), "%s"))'.format(location.get_uri()));
-            }));
+        locations.forEach((location) => {
+            filters.push('(fn:contains (nie:url(?urn), "%s"))'.format(location.get_uri()));
+        });
 
         filters.push('(fn:starts-with (nao:identifier(?urn), "gd:collection:local:"))');
 
         return '(' + filters.join(' || ') + ')';
-    },
+    }
 
-    getFilter: function() {
+    getFilter() {
         let filters = [];
 
         if (this.id == SearchSourceStock.LOCAL) {
@@ -403,9 +383,9 @@ const Source = new Lang.Class({
         }
 
         return '(' + filters.join(' || ') + ')';
-    },
+    }
 
-    _buildFilterResource: function() {
+    _buildFilterResource() {
         let filter = '(false)';
 
         if (!this.builtin)
@@ -413,14 +393,11 @@ const Source = new Lang.Class({
 
         return filter;
     }
-});
+}
 
-const SourceManager = new Lang.Class({
-    Name: 'SourceManager',
-    Extends: Manager.BaseManager,
-
-    _init: function(context) {
-        this.parent(_("Sources"), 'search-source', context);
+const SourceManager = class SourceManager extends Manager.BaseManager {
+    constructor(context) {
+        super(_("Sources"), 'search-source', context);
 
         let source = new Source({ id: SearchSourceStock.ALL,
         // Translators: this refers to documents
@@ -434,38 +411,37 @@ const SourceManager = new Lang.Class({
                               builtin: true });
         this.addItem(source);
 
-        Application.goaClient.connect('account-added', Lang.bind(this, this._refreshGoaAccounts));
-        Application.goaClient.connect('account-changed', Lang.bind(this, this._refreshGoaAccounts));
-        Application.goaClient.connect('account-removed', Lang.bind(this, this._refreshGoaAccounts));
+        Application.goaClient.connect('account-added', this._refreshGoaAccounts.bind(this));
+        Application.goaClient.connect('account-changed', this._refreshGoaAccounts.bind(this));
+        Application.goaClient.connect('account-removed', this._refreshGoaAccounts.bind(this));
 
         this._refreshGoaAccounts();
 
         this.setActiveItemById(SearchSourceStock.ALL);
-    },
+    }
 
-    _refreshGoaAccounts: function() {
+    _refreshGoaAccounts() {
         let newItems = {};
         let newSources = new Map();
         let accounts = Application.goaClient.get_accounts();
 
-        accounts.forEach(Lang.bind(this,
-            function(object) {
-                if (!object.get_account())
-                    return;
+        accounts.forEach((object) => {
+            if (!object.get_account())
+                return;
 
-                if (!object.get_documents())
-                    return;
+            if (!object.get_documents())
+                return;
 
-                let source = new Source({ object: object });
+            let source = new Source({ object: object });
 
-                let otherSources = newSources.get(source.name);
-                if (!otherSources)
-                    otherSources = [];
+            let otherSources = newSources.get(source.name);
+            if (!otherSources)
+                otherSources = [];
 
-                otherSources.push(source);
-                newSources.set(source.name, otherSources);
-                newItems[source.id] = source;
-            }));
+            otherSources.push(source);
+            newSources.set(source.name, otherSources);
+            newItems[source.id] = source;
+        });
 
         // Ensure an unique name for GOA accounts from the same provider
         newSources.forEach(function(sources, name) {
@@ -483,9 +459,9 @@ const SourceManager = new Lang.Class({
         });
 
         this.processNewItems(newItems);
-    },
+    }
 
-    getFilter: function(flags) {
+    getFilter(flags) {
         let item;
 
         if (flags & Query.QueryFlags.SEARCH)
@@ -501,9 +477,9 @@ const SourceManager = new Lang.Class({
             filter = item.getFilter();
 
         return filter;
-    },
+    }
 
-    getFilterNotLocal: function() {
+    getFilterNotLocal() {
         let sources = this.getItems();
         let filters = [];
 
@@ -517,9 +493,9 @@ const SourceManager = new Lang.Class({
             filters.push('false');
 
         return '(' + filters.join(' || ') + ')';
-    },
+    }
 
-    hasOnlineSources: function() {
+    hasOnlineSources() {
         let hasOnline = false;
         this.forEachItem(
             function(source) {
@@ -528,110 +504,98 @@ const SourceManager = new Lang.Class({
             });
 
         return hasOnline;
-    },
+    }
 
-    hasProviderType: function(providerType) {
+    hasProviderType(providerType) {
         let items = this.getForProviderType(providerType);
         return (items.length > 0);
-    },
+    }
 
-    getForProviderType: function(providerType) {
+    getForProviderType(providerType) {
         let items = [];
-        this.forEachItem(Lang.bind(this,
-            function(source) {
-                if (!source.object)
-                    return;
+        this.forEachItem((source) => {
+            if (!source.object)
+                return;
 
-                let account = source.object.get_account();
-                if (account.provider_type == providerType)
-                    items.push(source);
-            }));
+            let account = source.object.get_account();
+            if (account.provider_type == providerType)
+                items.push(source);
+        });
 
         return items;
     }
-});
+}
 
 var OFFSET_STEP = 50;
 
-const OffsetController = new Lang.Class({
-    Name: 'OffsetController',
-
-    _init: function() {
+const OffsetController = class OffsetController {
+    constructor() {
         this._offset = 0;
         this._itemCount = 0;
-    },
+    }
 
     // to be called by the view
-    increaseOffset: function() {
+    increaseOffset() {
         this._offset += OFFSET_STEP;
         this.emit('offset-changed', this._offset);
-    },
+    }
 
     // to be called by the model
-    resetItemCount: function() {
+    resetItemCount() {
         let query = this.getQuery();
 
-        Application.connectionQueue.add
-            (query.sparql, null, Lang.bind(this,
-                function(object, res) {
-                    let cursor = null;
-                    try {
-                        cursor = object.query_finish(res);
-                    } catch (e) {
-                        logError(e, 'Unable to execute count query');
-                        return;
+        Application.connectionQueue.add(
+            query.sparql, null, (object, res) => {
+                let cursor = null;
+                try {
+                    cursor = object.query_finish(res);
+                } catch (e) {
+                    logError(e, 'Unable to execute count query');
+                    return;
+                }
+
+                cursor.next_async(null, (object, res) => {
+                    let valid = object.next_finish(res);
+
+                    if (valid) {
+                        this._itemCount = cursor.get_integer(0);
+                        this.emit('item-count-changed', this._itemCount);
                     }
 
-                    cursor.next_async(null, Lang.bind(this,
-                        function(object, res) {
-                            let valid = object.next_finish(res);
+                    cursor.close();
+                });
+            });
+    }
 
-                            if (valid) {
-                                this._itemCount = cursor.get_integer(0);
-                                this.emit('item-count-changed', this._itemCount);
-                            }
-
-                            cursor.close();
-                        }));
-                }));
-    },
-
-    getQuery: function() {
+    getQuery() {
         log('Error: OffsetController implementations must override getQuery');
-    },
+    }
 
     // to be called by the model
-    resetOffset: function() {
+    resetOffset() {
         this._offset = 0;
-    },
+    }
 
-    getItemCount: function() {
+    getItemCount() {
         return this._itemCount;
-    },
+    }
 
-    getRemainingDocs: function() {
+    getRemainingDocs() {
         return (this._itemCount - (this._offset + OFFSET_STEP));
-    },
+    }
 
-    getOffsetStep: function() {
+    getOffsetStep() {
         return OFFSET_STEP;
-    },
+    }
 
-    getOffset: function() {
+    getOffset() {
         return this._offset;
     }
-});
+}
 Signals.addSignalMethods(OffsetController.prototype);
 
-var OffsetCollectionsController = new Lang.Class({
-    Name: 'OffsetCollectionsController',
-    Extends: OffsetController,
-
-    _init: function() {
-        this.parent();
-    },
-
-    getQuery: function() {
+var OffsetCollectionsController = class OffsetCollectionsController extends OffsetController {
+    getQuery() {
         let activeCollection = Application.documentManager.getActiveCollection();
         let flags;
 
@@ -642,30 +606,16 @@ var OffsetCollectionsController = new Lang.Class({
 
         return Application.queryBuilder.buildCountQuery(flags);
     }
-});
+}
 
-var OffsetDocumentsController = new Lang.Class({
-    Name: 'OffsetDocumentsController',
-    Extends: OffsetController,
-
-    _init: function() {
-        this.parent();
-    },
-
-    getQuery: function() {
+var OffsetDocumentsController = class OffsetDocumentsController extends OffsetController {
+    getQuery() {
         return Application.queryBuilder.buildCountQuery(Query.QueryFlags.DOCUMENTS);
     }
-});
+}
 
-var OffsetSearchController = new Lang.Class({
-    Name: 'OffsetSearchController',
-    Extends: OffsetController,
-
-    _init: function() {
-        this.parent();
-    },
-
-    getQuery: function() {
+var OffsetSearchController = class OffsetSearchController extends OffsetController {
+    getQuery() {
         return Application.queryBuilder.buildCountQuery(Query.QueryFlags.SEARCH);
     }
-});
+}
