@@ -27,9 +27,6 @@ const Gtk = imports.gi.Gtk;
 
 const Application = imports.application;
 
-const Lang = imports.lang;
-const Signals = imports.signals;
-
 const _ICON_VIEW_SIZE = 128;
 const _LIST_VIEW_SIZE = 48;
 
@@ -88,10 +85,9 @@ function iconFromRdfType(type) {
 }
 
 function getURNsFromPaths(paths, model) {
-    return paths.map(Lang.bind(this,
-            function(path) {
-                return getURNFromPath(path, model);
-            }));
+    return paths.map((path) => {
+        return getURNFromPath(path, model);
+    });
 }
 
 function getURNFromPath(path, model) {
@@ -114,13 +110,6 @@ function debug(str) {
         log('DEBUG: ' + str);
 }
 
-function addJSSignalMethods(proto) {
-    proto.connectJS = Signals._connect;
-    proto.disconnectJS = Signals._disconnect;
-    proto.emitJS = Signals._emit;
-    proto.disconnectAllJS = Signals._disconnectAll;
-}
-
 function actionToggleCallback(action) {
     let state = action.get_state();
     action.change_state(GLib.Variant.new('b', !state.get_boolean()));
